"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateSchema = exports.validateInt = exports.validateString = void 0;
const common_stuff_1 = require("common-stuff");
const ajv_1 = __importDefault(require("ajv"));
function validateString(value, name) {
    if (value == null || !value) {
        throw new common_stuff_1.HttpError(common_stuff_1.HttpStatusCodes.BAD_REQUEST, `${name} is required`);
    }
    if (typeof value === 'string') {
        return value;
    }
    throw new common_stuff_1.HttpError(common_stuff_1.HttpStatusCodes.BAD_REQUEST, `${name} must be string`);
}
exports.validateString = validateString;
function validateInt(value, name) {
    if (value == null || !value) {
        throw new common_stuff_1.HttpError(common_stuff_1.HttpStatusCodes.BAD_REQUEST, `${name} is required`);
    }
    const parsed = typeof value === 'number'
        ? value
        : typeof value === 'string'
            ? parseFloat(value)
            : undefined;
    if (typeof parsed === 'number' && !isNaN(parsed)) {
        return parsed;
    }
    throw new common_stuff_1.HttpError(common_stuff_1.HttpStatusCodes.BAD_REQUEST, `${name} must be number`);
}
exports.validateInt = validateInt;
function validateSchema(schema, data, options) {
    const { name = 'data' } = options || {};
    const ajv = new ajv_1.default({ allErrors: true });
    if (!ajv.validate(schema, data)) {
        throw new common_stuff_1.HttpError(common_stuff_1.HttpStatusCodes.BAD_REQUEST, ajv.errorsText(null, {
            dataVar: name,
        }));
    }
    return data;
}
exports.validateSchema = validateSchema;
